@@ -573,6 +573,7 @@ anubis_authenticate_mode (NET_STREAM *psd_client,
   if (usr.username)
     {
       strncpy (session.clientname, usr.username, sizeof (session.clientname));
+      session.clientname[sizeof (session.clientname) - 1] = '\0';
       if (check_username (session.clientname))
 	anubis_changeowner (session.clientname);
       else
@@ -582,6 +583,7 @@ anubis_authenticate_mode (NET_STREAM *psd_client,
     {
       strncpy (session.clientname, usr.smtp_authid,
 	       sizeof (session.clientname));
+      session.clientname[sizeof (session.clientname) - 1] = '\0';
       set_unprivileged_user ();
     }
 
@@ -729,7 +731,7 @@ rc_parser (int method, int key, ANUBIS_LIST * arglist,
     break;
     
   case KW_SASL_ALLOWED_MECH:
-    anubis_set_mech_list (arglist);
+    anubis_set_server_mech_list (arglist);
     break;
 
   default:
