@@ -23,6 +23,7 @@
 */
 
 #include "headers.h"
+#include <grp.h>
 #include <getopt.h>
 #include "extern.h"
 #include "rcfile.h"
@@ -49,12 +50,15 @@ argv_dup (int argc, char **argv)
 
 static int gindex = 0;
 
+static char *pidfile;
+
 #define OPT_VERSION          257
 #define OPT_HELP             258
 #define OPT_ALTRC            259
 #define OPT_NORC             260
 #define OPT_SHOW_CONFIG      261
 #define OPT_RELAX_PERM_CHECK 262
+#define OPT_PIDFILE          263
 
 static struct option gopt[] = {
   {"bind", required_argument, 0, 'b'},
@@ -72,6 +76,7 @@ static struct option gopt[] = {
   {"check-config", optional_argument, 0, 'c'},
   {"show-config-options", no_argument, 0, OPT_SHOW_CONFIG},
   {"relax-perm-check", no_argument, 0, OPT_RELAX_PERM_CHECK},
+  {"pid-file", required_argument, 0, OPT_PIDFILE},
 #ifdef WITH_GSASL
   {"mode", required_argument, 0, 'm'},
 #endif
@@ -113,6 +118,10 @@ get_options (int argc, char *argv[])
 	  topt |= T_RELAX_PERM_CHECK;
 	  break;
 
+	case OPT_PIDFILE:
+	  pidfile = optarg;
+	  break;
+	    
 	case 'c':
 	  rc_set_debug_level (optarg);
 	  topt |= T_CHECK_CONFIG;
@@ -246,6 +255,107 @@ check_superuser (void)
  Set USER's RGID, RUID, and home directory.
 ********************************************/
 
+/* Change to the given uid/gid. Clear the supplementary group list.
+   On success returns 0.
+   On failure returns 1 (or exits, depending on topt settings. See
+   anubis_error) */
+static int
+change_privs (uid_t uid, gid_t gid)
+{
+  int rc = 0;
+  gid_t emptygidset[1];
+
+  /* Reset group permissions */
+  emptygidset[0] = gid ? gid : getegid();
+  if (geteuid() == 0 && setgroups(1, emptygidset))
+    {
+      anubis_error (0, errno,
+		    _("setgroups(1, %lu) failed"),
+		    (u_long) emptygidset[0]);
+      rc = 1;
+    }
+
+  /* Switch to the user's gid. On some OSes the effective gid must
+     be reset first */
+
+#if defined(HAVE_SETEGID)
+  if ((rc = setegid(gid)) < 0)
+    anubis_error (0, errno, _("setegid(%lu) failed"), (u_long) gid);
+#elif defined(HAVE_SETREGID)
+  if ((rc = setregid(gid, gid)) < 0)
+    anubis_error (0, errno, _("setregid(%lu,%lu) failed"),
+		  (u_long) gid, (u_long) gid);
+#elif defined(HAVE_SETRESGID)
+  if ((rc = setresgid(gid, gid, gid)) < 0)
+    anubis_error (0, errno, _("setresgid(%lu,%lu,%lu) failed"),
+		  (u_long) gid,
+		  (u_long) gid,
+		  (u_long) gid);
+#endif
+
+  if (rc == 0 && gid != 0)
+    {
+      if ((rc = setgid(gid)) < 0 && getegid() != gid) 
+	anubis_error (0, errno, _("setgid(%lu) failed"), (u_long) gid);
+      if (rc == 0 && getegid() != gid)
+	{
+	  anubis_error (0, errno, _("cannot set effective gid to %lu"),
+			(u_long) gid);
+	  rc = 1;
+	}
+    }
+
+  /* Now reset uid */
+  if (rc == 0 && uid != 0)
+    {
+      uid_t euid;
+
+      if (setuid(uid)
+	  || geteuid() != uid
+	  || (getuid() != uid
+	      && (geteuid() == 0 || getuid() == 0)))
+	{
+			
+#if defined(HAVE_SETREUID)
+	  if (geteuid() != uid)
+	    {
+	      if (setreuid(uid, -1) < 0)
+		{
+		  anubis_error (0, errno, _("setreuid(%lu,-1) failed"),
+				(u_long) uid);
+		  rc = 1;
+		}
+	      if (setuid(uid) < 0)
+		{
+		  anubis_error (0, errno, _("second setuid(%lu) failed"),
+				(u_long) uid);
+		  rc = 1;
+		}
+	    }
+	  else
+#endif
+	    {
+	      anubis_error (0, errno, _("setuid(%lu) failed"), (u_long) uid);
+	      rc = 1;
+	    }
+	}
+	
+
+      euid = geteuid();
+      if (uid != 0 && setuid(0) == 0)
+	{
+	  anubis_error (0, 0, _("seteuid(0) succeeded when it should not"));
+	  rc = 1;
+	}
+      else if (uid != euid && setuid(euid) == 0)
+	{
+	  anubis_error (0, 0, _("cannot drop non-root setuid privileges"));
+	  rc = 1;
+	}
+    }
+  return rc;
+}
+
 void
 anubis_changeowner (char *user)
 {
@@ -277,8 +387,9 @@ anubis_changeowner (char *user)
   pwd = getpwnam (user);
   if (pwd)
     {
-      setgid (pwd->pw_gid);
-      setuid (pwd->pw_uid);
+      if (change_privs (pwd->pw_uid, pwd->pw_gid))
+	quit (EXIT_FAILURE);
+	
       chdir (pwd->pw_dir);
       info (VERBOSE, _("UID:%d (%s), GID:%d, EUID:%d, EGID:%d"),
 	    (int) getuid (), pwd->pw_name, (int) getgid (),
@@ -344,7 +455,7 @@ check_filemode (char *path)
     return 0;
   if ((st.st_mode & S_IRWXG) || (st.st_mode & S_IRWXO))
     {
-      anubis_error (SOFT, _("Wrong permissions on %s. Set 0600."), path);
+      anubis_error (0, 0, _("Wrong permissions on %s. Set 0600."), path);
       return 0;			/* FALSE */
     }
   return 1;			/* TRUE */
@@ -364,12 +475,12 @@ check_filename (char *path, time_t *timep)
 
   if (stat (path, &st) == -1)
     {
-      anubis_error (HARD, "%s: %s.", path, strerror (errno));
+      anubis_error (0, errno, "%s", path);
       return 0;			/* FALSE */
     }
   if (!(st.st_mode & S_IFREG) || !(st.st_mode & S_IFLNK))
     {
-      anubis_error (HARD,
+      anubis_error (0, 0,
 		    _("%s is not a regular file or a symbolic link."), path);
       return 0;			/* FALSE */
     }
@@ -399,4 +510,20 @@ anubis_set_mode (char *modename)
   return 0;
 }
 
+void
+write_pid_file (void)
+{
+  FILE *fp;
+  
+  if (!pidfile)
+    pidfile = "/var/run/" DEFAULT_PIDFILE;
+  fp = fopen (pidfile, "w");
+  if (!fp)
+    anubis_error (0, errno, _("Cannot open pid file '%s'"), pidfile);
+  else 
+    {
+      fprintf (fp, "%ld\n", (unsigned long) getpid ());
+      fclose (fp);
+    }
+}
 /* EOF */
