@@ -1,5 +1,5 @@
 /*
-   GNU Anubis v3.9.95 -- an outgoing mail processor and the SMTP tunnel.
+   GNU Anubis v4.0 -- an SMTP message submission daemon.
    Copyright (C) 2001, 2002, 2003, 2004 The Anubis Team.
 
    GNU Anubis is free software; you can redistribute it and/or modify
@@ -55,7 +55,7 @@ anubis_core (void)
 static void
 anubis_memory_error (const char *msg)
 {
-  anubis_error (EXIT_FAILURE, 0, msg);
+  anubis_error (EXIT_FAILURE, 0, "%s", msg);
 }
 
 int
